@@ -266,7 +266,7 @@ def save_account_key(bucket, ns, content, tmp_dir, profile):
     if isinstance(content, str):
         content = content.encode('utf-8')
     s3_key = filename
-    s3.put_object(Bucket=bucket, Key=s3_key, Body=content)
+    s3.put_object(Bucket=bucket, Key=s3_key, Body=content, ACL='bucket-owner-full-control')
 
 
 def save_key(bucket, ns, hostname, content, tmp_dir, profile):
@@ -278,7 +278,7 @@ def save_key(bucket, ns, hostname, content, tmp_dir, profile):
     if isinstance(content, str):
         content = content.encode('utf-8')
     s3_key = posixpath.join(ns, filename)
-    s3.put_object(Bucket=bucket, Key=s3_key, Body=content)
+    s3.put_object(Bucket=bucket, Key=s3_key, Body=content, ACL='bucket-owner-full-control')
 
 
 def pfx(ctx, certificate, key):
@@ -456,7 +456,7 @@ def save_to_s3(ctx, bucket, ns, hostname, certificate, account_key, key,
         log.info('saving s3://%s/%s', bucket, filename)
         if isinstance(content, str):
             content = content.encode('utf-8')
-        s3.put_object(Bucket=bucket, Key=filename, Body=content)
+        s3.put_object(Bucket=bucket, Key=filename, Body=content, ACL='bucket-owner-full-control')
 
 
 def save_to_ssm(ctx, ns, hostname, certificate, account_key, key, profile=None):
